From c7d1373554910102846123afb35c8c1a842f2c9a Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Micha=C5=82=20G=C3=B3rny?= <mgorny@gentoo.org>
Date: Tue, 17 May 2022 07:26:36 +0200
Subject: [PATCH] Replace pytest-relaxed with plain pytest.raises

There is really no technical reason to bring pytest-relaxed to call
@raises as a decorator while plain pytest works just fine.  Plus,
pytest.raises() is used in test_sftp already.

pytest-relaxed causes humongous breakage to other packages
on the system.  It has been banned from Gentoo for this reason.
---
 dev-requirements.txt |  6 ++++++
 pytest.ini           |  3 ---
 tests/test_client.py | 19 +++++++++----------
 3 files changed, 15 insertions(+), 13 deletions(-)

diff --git a/tests/test_client.py b/tests/test_client.py
index dae5b13a..d0e9c434 100644
--- a/tests/test_client.py
+++ b/tests/test_client.py
@@ -33,7 +33,6 @@ import weakref
 from tempfile import mkstemp
 
 import pytest
-from pytest_relaxed import raises
 from unittest.mock import patch, Mock
 
 import paramiko
@@ -786,11 +785,11 @@ class PasswordPassphraseTests(ClientTest):
 
     # TODO: more granular exception pending #387; should be signaling "no auth
     # methods available" because no key and no password
-    @raises(SSHException)
     @requires_sha1_signing
     def test_passphrase_kwarg_not_used_for_password_auth(self):
-        # Using the "right" password in the "wrong" field shouldn't work.
-        self._test_connection(passphrase="pygmalion")
+        with pytest.raises(SSHException):
+            # Using the "right" password in the "wrong" field shouldn't work.
+            self._test_connection(passphrase="pygmalion")
 
     @requires_sha1_signing
     def test_passphrase_kwarg_used_for_key_passphrase(self):
@@ -810,15 +809,15 @@ class PasswordPassphraseTests(ClientTest):
             password="television",
         )
 
-    @raises(AuthenticationException)  # TODO: more granular
     @requires_sha1_signing
     def test_password_kwarg_not_used_for_passphrase_when_passphrase_kwarg_given(  # noqa
         self,
     ):
         # Sanity: if we're given both fields, the password field is NOT used as
         # a passphrase.
-        self._test_connection(
-            key_filename=_support("test_rsa_password.key"),
-            password="television",
-            passphrase="wat? lol no",
-        )
+        with pytest.raises(AuthenticationException):
+            self._test_connection(
+                key_filename=_support("test_rsa_password.key"),
+                password="television",
+                passphrase="wat? lol no",
+            )
-- 
2.39.1

From becd215434a7c01c74b407cbf2cbcb192e138a15 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Micha=C5=82=20G=C3=B3rny?= <mgorny@gentoo.org>
Date: Sat, 21 Jan 2023 06:56:09 +0100
Subject: [PATCH] Remove icecream dep

---
 tests/conftest.py | 6 ------
 1 file changed, 6 deletions(-)

diff --git a/tests/conftest.py b/tests/conftest.py
index b28d2a17..3cecb7e8 100644
--- a/tests/conftest.py
+++ b/tests/conftest.py
@@ -10,12 +10,6 @@ from .loop import LoopSocket
 from .stub_sftp import StubServer, StubSFTPServer
 from .util import _support
 
-from icecream import ic, install as install_ic
-
-
-install_ic()
-ic.configureOutput(includeContext=True)
-
 
 # Perform logging by default; pytest will capture and thus hide it normally,
 # presenting it on error/failure. (But also allow turning it off when doing
-- 
2.39.1

